@@ -3,7 +3,7 @@ import warnings
 from augpathlib import exceptions as exc
 from augpathlib.meta import PathMeta
 from augpathlib.core import AugmentedPath, EatPath
-from augpathlib.utils import log, default_cypher
+from augpathlib.utils import log, default_cypher, fs_safe_id
 from augpathlib.utils import LOCAL_DATA_DIR, SPARSE_MARKER
 from augpathlib import remotes
 
@@ -133,6 +133,7 @@ class CachePath(AugmentedPath):
                 raise exc.NoCachedMetadataError(self.local)
 
             elif isinstance(path, LocalPath):
+                # XXX FIXME probably remove this
                 path._cache = self
 
         super().__init__()
@@ -150,18 +151,32 @@ class CachePath(AugmentedPath):
 
     @property
     def _trashed_path(self):
-        return self.trash / f'{self.parent.id}-{self.id}-{self.name}'
+        # XXX warning this can overflow file name length
+        # you should probably override this for your specific application
+        # because by default this probably does not provide a pointer back
+        # to where the file originally lived and you would need to store
+        # that information elsewhere if you want to be able to restore
+        # logging the moves might work
+        return self.trash / fs_safe_id(self.id)
 
     @property
     def _trashed_path_short(self):
         return self.trash / self.name  # FIXME SIGH
 
     def crumple(self):  # FIXME change name to something more obvious ...
+        trashed = self._trashed_path
+        tp = trashed.parent
+        if not tp.exists():
+            # we can ensure that self.trash exists at startup
+            # but if a subclass adds intervening folders, we
+            # need to catch that here and create them
+            tp.mkdir(parents=True)
+
         try:
-            self.rename(self._trashed_path)
+            self.rename(trashed)
         except OSError as e:
             if e.errno == 36:  # File name too long  # SIGH
-                log.critical(f'Had to rename trash {self._trashed_path} -> {self._trashed_path_short}')
+                log.critical(f'Had to rename trash {trashed} -> {self._trashed_path_short}')
                 self.rename(self._trashed_path_short)
             else:
                 raise e
@@ -200,11 +215,21 @@ class CachePath(AugmentedPath):
             # NOTE this whole design is dumb, and in cases where
             # there are just remote objects we should be stashing
             # them in ~/.cache or similar
-            if self.local_objects_dir.is_symlink():
+            if lod.is_symlink():
                 msg = f'{lod} is already symlinked to {lod.readlink()}'
+                if lod.resolve() == symlink_objects_to.resolve():
+                    log.info(msg)
+                    return
+
                 raise NotADirectoryError(msg)
             elif lod.exists():
-                lod.rmdir()
+                try:
+                    lod.rmdir()
+                except OSError as e:
+                    msg = ('local objects dir already exists did you mean '
+                           'to run with symlink_objects_to set?')
+                    log.error(msg)
+                    raise e
 
             lod.symlink_to(symlink_objects_to)
         else:
@@ -552,6 +577,11 @@ class CachePath(AugmentedPath):
         anchor = self.anchor
         if anchor is None:  # the very first ...
             # in which case we need the id for factory AND class
+            if not self.is_absolute():
+                # OR we are dealing with a relative path
+                # can't use resolve because we might be on a circular symlink
+                return self.absolute().remote
+
             self._bootstrapping_id = id  # so we set it again
             anchor = self  # could double check if the id has the info too ...
 
@@ -690,7 +720,6 @@ class CachePath(AugmentedPath):
 
         root = self.parent.local.find_cache_root()
         if root is None:
-            #breakpoint()
             raise exc.NotInProjectError(f'{self.parent.local} is not in a project!')
 
         breakpoint()
@@ -768,7 +797,7 @@ class CachePath(AugmentedPath):
         else:
             log.info(f'Remote for {self} has been deleted. Moving to trash.')
             try:
-                self.rename(self.trash / f'{self.parent.id}-{self.id}-{self.name}')
+                self.rename(self._trashed_path)
             except FileNotFoundError as e:
                 if not self.trash.exists():
                     self.trash.mkdir()
@@ -796,8 +825,25 @@ class CachePath(AugmentedPath):
                 self.touch()
                 self._meta_setter(meta)
 
+            # FIXME I'm 99% certain that our mysterious zero size files are happening here
+            # and the error is getting caught and silence somehow
             log.info(f'Fetching remote via cache id {self.id} -> {self.local}')
+            existing_cache_cache = self.local_object_cache_path.exists()
             self.local.data = self.data  # note that this should trigger storage to .ops/objects
+            if self.local.size != meta.size:
+                m2 = '.operations/objects/' + self.id.replace(':', '\:')  # FIXME not abstracted
+                msg = (f'{self.local.size} != {meta.size} for {self.local}\n{m2}\n'
+                       f'from previous fetch? {existing_cache_cache}')
+                raise ValueError(msg)
+
+            _lc = self.local.checksum()
+            if meta.checksum is not None and _lc != meta.checksum:
+                # FIXME these checks need to be happning inside of
+                # the local.data setter since otherwise this is overkill
+                #breakpoint()
+                msg = f'{_lc!r} != {meta.checksum!r} for {self!r}'
+                log.critical(msg)
+                #raise BaseException()
 
         if size_not_ok:
             log.warning(f'File is over the size limit {meta.size.mb} > {size_limit_mb}')
@@ -917,6 +963,7 @@ ReflectiveCache._bind_flavours()
 
 
 class EatCache(EatPath, CachePath):
+
     xattr_prefix = None
 
     @property
@@ -984,18 +1031,44 @@ class SymlinkCache(CachePath):
 
     @property
     def meta(self):
+        # LOL PYTHON
+        # Oh, you wanted to abstract that property for use on another
+        # class?  I'm sorry, we don't allow that here, if you call any
+        # instance functions you will have to manually include all of
+        # those on the other class too. SIGH.
+
+        # Or you do what we do here which is ensure that the
+        # implementation of a property for a class is always tied to
+        # that class which is implicit when you define code in a
+        # property, but is immediately lost the second you call out to
+        # instance function which could be different in the class that
+        # wants to reuse the property
+        return SymlinkCache._meta_impl(self)
+
+    @classmethod
+    def _meta_impl(cls, self, match_name=True):
         if hasattr(self, '_meta'):
             return self._meta
 
         if self.is_symlink():
             if not self.exists():  # if a symlink exists it is something other than what we want
                 #assert pathlib.PurePosixPath(self.name) == self.readlink().parent.parent
-                return PathMeta.from_symlink(self)
+                return PathMeta.from_symlink(self, match_name=match_name)
             else:
-                raise exc.PathExistsError(f'Target of symlink exists!\n{self} -> {self.resolve()}')
+                msg = f'Target of symlink exists!\n{self} -> {self.resolve()}'
+                raise exc.PathExistsError(msg)
 
         else:
-            return super().meta
+            raise exc.NoCachedMetadataError(self)
+
+            # XXX actually I think calling into super was a hold-over
+            # from an old broken implementation that simply needs to
+            # be removed, because all the callers of SymlinkCache().meta
+            # expect it to fail, not return some other metadata
+
+            # you have to pass type(self) and self to super
+            # otherwise you get the cls.meta property
+            #return super(type(self), self).meta
 
     @meta.setter
     def meta(self, pathmeta):
@@ -1061,9 +1134,22 @@ class SymlinkCache(CachePath):
                 log.debug('Metadata exists, but ids match so will update')
 
                 # trash old versions instead of just unlinking
-                pc = self.local.cache
-                trash = pc.trash
-                self.rename(trash / f'{pc.parent.id}-{meta.id}-{self.name}')
+                primary_cache = self.local.cache
+                # the primary cache has the same path as self which
+                # means that we can call crumple directly on the
+                # primary_cache and it will behave correctly trying to
+                # use primary_cache._trashed_path directly could fail
+                # if the trashed path has a non-existent parent
+                try:
+                    primary_cache.crumple()
+                except FileExistsError:
+                    # a file by this name with this id has already been
+                    # crumpled so we unlink here instead
+                    self.unlink()
+
+                #self.rename(pc._trashed_path)
+                #trash = pc.trash
+                #self.rename(trash / fs_safe_id(f'{pc.parent.id}-{meta.id}-{self.name}'))
                 #self.unlink()
 
             # FIXME if an id starts with / then the local name is overwritten due to pathlib logic
@@ -1080,6 +1166,7 @@ SymlinkCache._bind_flavours()
 
 
 class PrimaryCache(CachePath):
+
     @property
     def meta(self):
         #if hasattr(self, '_in_bootstrap'):
@@ -1296,3 +1383,4 @@ SshCache._bind_flavours()
 
 from augpathlib.core import LocalPath
 SshCache._local_class = LocalPath
+ReflectiveCache._local_class = LocalPath
