@@ -34,6 +34,7 @@ _IGNORED_ERROS = (ENOENT, ENOTDIR, EBADF, ELOOP)
 _IGNORED_WINERRORS = (
     123,  # 'The filename, directory name, or volume label syntax is incorrect' -> 22 EINVAL
 )
+
 if sys.platform == 'darwin':
     _IGNORED_ERROS += (errno.ENAMETOOLONG,)
 
@@ -55,6 +56,8 @@ else:
 
 if sys.version_info >= (3, 7):
     pathlib._IGNORED_ERROS += (ELOOP,)
+    pathlib._IGNORED_WINERRORS += _IGNORED_WINERRORS
+    _IGNORED_WINERRORS = pathlib._IGNORED_WINERRORS
     if sys.platform == 'darwin':
         # darwin gets very confused by self referential symlinks
         # and it seems that they stack up on eachother while being
@@ -133,6 +136,8 @@ class ADSHelper(EatHelper):
         return namespace + '.' + key  # FIXME maybe include xattrs. as well ??
 
     def _stream(self, name):
+        # FIXME single char folder names are completely evil here
+        # you they are not absolute and they resolve to themselves
         *start, last = self.parts
         if not start and len(last) == 1:
             # single letter file names with no extension
@@ -140,7 +145,7 @@ class ADSHelper(EatHelper):
             # there seems to be nothing we can do about it
             raise ValueError('windows and single letter file names dont get along')
 
-        return AugmentedPath(*start, last + ':' + name)
+        return AugmentedPath(*start, './' + last + ':' + name)
 
     @property
     def _streamname(self):
@@ -214,6 +219,7 @@ class ADSHelper(EatHelper):
             f.write(bytes_value)
 
     def setxattrs(self, xattr_dict, namespace=XATTR_DEFAULT_NS):
+        # FIXME this is almost certainly bugged for Path('.') too
         for k, v in xattr_dict.items():
             self.setxattr(k, v, namespace=namespace)
 
@@ -228,6 +234,14 @@ class ADSHelper(EatHelper):
             raise exc.NoStreamError((self, key)) from e
 
     def _xattrs(self):
+        if not self.is_absolute():
+            # the nature of the '.' path on windows means that
+            # _streams will severly misbehave so we resolve the path
+            # before retrieving streams, note that you can shoot
+            # yourself in the foot if you are carrying around an
+            # unresolved path and are not where you think you are
+            self = self.resolve()
+
         out = {}
         for stream in self._streams:
             _base, k = stream.name.split(':', 1)
@@ -239,6 +253,9 @@ class ADSHelper(EatHelper):
         return out
 
     def xattrs(self, namespace=XATTR_DEFAULT_NS):
+        # FIXME broken for Path('.') causes an error in _stream
+        # FIXME broken if run with path: path.xattrs() -> returns {}
+        # I think that on windows these paths must always be resolved?
         # decode keys later
         ns_length_p1 = len(namespace) + 1
         try:
@@ -488,7 +505,7 @@ class AugmentedPath(pathlib.Path):
             temp.rename(self)
             temp_dir.rmdir()
 
-    if sys.platform != 'linux': # just look at us not using pathlib's infra ...
+    if sys.platform != 'linux':  # just look at us not using pathlib's infra ...
         _swap = swap.swap_not_implemented
     else:
         _swap = swap.swap_linux
@@ -612,12 +629,23 @@ class AugmentedPath(pathlib.Path):
 
     @property
     def mimetype(self):
+        if self.is_dir():
+            return 'inode/directory'  # matches _magic_mimetype
+
         if not self.is_absolute():  # needed for safe as_uri
-            self = self.resolve()
+            if self.is_broken_symlink():
+                self = self.absolute()
+            else:
+                self = self.resolve()
 
         mime, encoding = mimetypes.guess_type(self.as_uri())
         if mime:
             return mime
+        elif hasattr(self, '_suffix_mimetypes') and self._suffix_mimetypes:
+            # FIXME TODO make a real interface for these
+            suffixes = tuple(self.suffixes)
+            if suffixes in self._suffix_mimetypes:
+                return self._suffix_mimetypes[suffixes]
 
     @property
     def encoding(self):
@@ -810,6 +838,18 @@ class LocalPath(EatPath, AugmentedPath):
 
     _bind_sysid = classmethod(_bind_sysid_)
 
+    def __new__(cls, *args, **kwargs):
+        self = super().__new__(cls, *args, **kwargs)
+        #if args and isinstance(args[0], LocalPath):
+            # XXX I'm sure this will break cases where we want to change from
+            # one cache class to another by changing which local path class we
+            # construct, but wow this is way too far gone already
+            # XXX AAAAND it has, and it is extremely insanity inducing and
+            # hard to debug
+            #self._cache_class = args[0]._cache_class
+
+        return self
+
     @classmethod
     def setup(cls, cache_class, remote_class_factory):
         """ call this once to bind everything together """
@@ -839,13 +879,19 @@ class LocalPath(EatPath, AugmentedPath):
         # otherwise it will error (correctly)
         if not hasattr(self, '_cache'):
             try:
-                self._cache_class(self)  # we don't have to assign here because cache does it
+                self._cache = self._cache_class(self)
+                # +we don't have to assign here because cache does it+ XXX
+                # assign here anyway because it makes it clear what is going on
+                # and avoids spooky action at a distance and avoids implicit
+                # expectations on the cache constructor
             except exc.NoCachedMetadataError as e:
                 #log.error(e)
                 return None
             except TypeError as e:
                 if self._cache_class is None:
                     return None
+                else:
+                    raise e
 
         return self._cache
 
@@ -1138,6 +1184,30 @@ class LocalPath(EatPath, AugmentedPath):
 
                 yield data
 
+    def _write_chunks_ntfs(self, generator):
+        # SO. It turns out that open(thing, 'wb') has fundamentally different
+        # semantics on posix and windows (wheeeeeeeeeee!) on posix it keeps
+        # xattrs intact, on windows it erases them AAAAAAAAAAAAAAAAAAAAAAA
+        chunk1 = next(generator)  # if an error occurs don't open the file FIXME I think this might be causing the zero size files?
+        with open(self, 'ab') as f:
+            f.seek(0)
+            f.truncate()
+            f.write(chunk1)
+            for chunk in generator:
+                #log.debug(chunk)
+                f.write(chunk)
+
+    def _write_chunks_posix(self, generator):
+        chunk1 = next(generator)  # if an error occurs don't open the file FIXME I think this might be causing the zero size files?
+        with open(self, 'wb') as f:
+            f.write(chunk1)
+            for chunk in generator:
+                #log.debug(chunk)
+                f.write(chunk)
+
+    _write_chunks = (
+        _write_chunks_ntfs if os.name == 'nt' else _write_chunks_posix)
+
     @data.setter
     def data(self, generator):
         cache = self.cache
@@ -1154,25 +1224,25 @@ class LocalPath(EatPath, AugmentedPath):
         # especially when updating a file ...
         # storing history in the symlink cache also an option?
         log.debug(f'writing to {self}')
-        chunk1 = next(generator)  # if an error occurs don't open the file
-        with open(self, 'wb') as f:
-            f.write(chunk1)
-            for chunk in generator:
-                #log.debug(chunk)
-                f.write(chunk)
-
+        self._write_chunks(generator)
         if cache is not None:  # FIXME cache
             if not cache.meta:
+                # XXX FIXME when this fails to set things downstream fail as well
+                # so we see things like None type has no attribute xyz because the
+                # cached metadata didn't get set correctly, this is happening in
+                # some subclass where cache.meta doesn't have a setter
                 cache.meta = cmeta  # glories of persisting xattrs :/
             # yep sometimes the xattrs get  blasted >_<
             assert cache.meta
             assert self.cache.meta
 
-    def _data_setter(self, generator):
+    def _data_setter(self, generator, append=False):  # FIXME ntfs ads issues
         """ a data setter that can be used in a chain of generators """
+        # FIXME if the generator can silently fail that is very very bad news ...
+        # but how/why would they be silently failing ??!
         log.debug(f'writing to {self}')
         chunk1 = next(generator)  # if an error occurs don't open the file
-        with open(self, 'wb') as f:
+        with open(self, 'ab' if append else 'wb') as f:
             f.write(chunk1)
             yield chunk1
             for chunk in generator:
