@@ -1,3 +1,4 @@
+import os
 import sys
 import unittest
 from pathlib import PurePosixPath
@@ -75,6 +76,31 @@ class TestAugPath(Helper, unittest.TestCase):
         # this doesn't test passing deeper ...
         self.test_path.rmtree(ignore_errors=True, onerror=onerror)
 
+    def test_rmtree_symlinks(self):
+        """ make sure we don't rmtree through symlinks """
+        tp = self.test_path
+        tp.mkdir()
+        d = tp / 'dir'
+        t = tp / 'dir/target'
+        f = tp / 'dir/target/file'
+        so = tp / 'dir/source'
+        s = tp / 'dir/source/symlink'
+        d.mkdir()
+        t.mkdir()
+        f.touch()
+        so.mkdir()
+        s.symlink_to(t)
+        try:
+            s.rmtree()
+            assert False, 'should have failed!'
+        except OSError:
+            pass
+
+        so.rmtree()
+        assert not so.exists()
+        assert f.exists() and t.exists()
+        self.test_path.rmtree(onerror=onerror)
+
     def test_relative_path_from(self):
         p1 = self.test_path / 'a' / 'b' / 'c' / 'd'
         p2 = self.test_path / 'e' / 'f' / 'g' / 'h'
@@ -85,6 +111,25 @@ class TestAugPath(Helper, unittest.TestCase):
         assert e1 == p1rfp2, p1rfp2
         assert e2 == p2rfp1, p2rfp1
 
+
+@pytest.mark.skipif(os.name == 'nt', reason='no easy way to get libmagic on windows')
+class TestMimetype(Helper, unittest.TestCase):
+    def setUp(self):
+        super().setUp()
+        self.tf = self.test_path / 'some-text.txt'
+        self.test_path.mkdir()
+        with open(self.tf, 'wt') as f:
+            f.write('hello')
+
+    def test_mimetype(self):
+        mt = self.tf.mimetype
+        assert mt == 'text/plain', mt
+
+    def test_magic_mimetype(self):
+        mmt = self.tf._magic_mimetype
+        assert mmt == 'text/plain', mmt
+
+
 class TestAugPathCopy(Helper, unittest.TestCase):
 
     def setUp(self):
